@@ -4,7 +4,7 @@ from clidirector import CliDirector
 import screenplays
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     director = CliDirector()
     screenplays.record_user_interface(director)
     screenplays.record_intercept_requests(director)
