@@ -3,7 +3,7 @@
 from mitmproxy import flowfilter
 
 
-print("<table class=\"table filtertable\"><tbody>")
+print('<table class="table filtertable"><tbody>')
 for i in flowfilter.help:
     print("<tr><th>%s</th><td>%s</td></tr>" % i)
 print("</tbody></table>")
