@@ -10,12 +10,11 @@ class Filter:
         self.filter: flowfilter.TFilter = None
 
     def configure(self, updated):
-        self.filter = flowfilter.parse(ctx.options.flowfilter)
+        if "flowfilter" in updated:
+            self.filter = flowfilter.parse(ctx.options.flowfilter)
 
     def load(self, l):
-        l.add_option(
-            "flowfilter", str, "", "Check that flow matches filter."
-        )
+        l.add_option("flowfilter", str, "", "Check that flow matches filter.")
 
     def response(self, flow: http.HTTPFlow) -> None:
         if flowfilter.match(self.filter, flow):
