@@ -2,7 +2,7 @@
 """
 Read a mitmproxy dump file.
 """
-from mitmproxy import io
+from mitmproxy import io, http
 from mitmproxy.exceptions import FlowReadException
 import pprint
 import sys
@@ -13,7 +13,8 @@ with open(sys.argv[1], "rb") as logfile:
     try:
         for f in freader.stream():
             print(f)
-            print(f.request.host)
+            if isinstance(f, http.HTTPFlow):
+                print(f.request.host)
             pp.pprint(f.get_state())
             print("")
     except FlowReadException as e:
