@@ -1,5 +1,5 @@
 """React to configuration changes."""
-import typing
+from typing import Optional
 
 from mitmproxy import ctx
 from mitmproxy import exceptions
@@ -8,10 +8,10 @@ from mitmproxy import exceptions
 class AddHeader:
     def load(self, loader):
         loader.add_option(
-            name = "addheader",
-            typespec = typing.Optional[int],
-            default = None,
-            help = "Add a header to responses",
+            name="addheader",
+            typespec=Optional[int],
+            default=None,
+            help="Add a header to responses",
         )
 
     def configure(self, updates):
@@ -24,6 +24,4 @@ class AddHeader:
             flow.response.headers["addheader"] = str(ctx.options.addheader)
 
 
-addons = [
-    AddHeader()
-]
+addons = [AddHeader()]
