@@ -1,10 +1,10 @@
 import asyncio
+import traceback
 import urllib.parse
 
 import asgiref.compatibility
 import asgiref.wsgi
 from mitmproxy import ctx, http
-from mitmproxy.controller import DummyReply
 
 
 class ASGIApp:
@@ -25,18 +25,16 @@ class ASGIApp:
         return f"asgiapp:{self.host}:{self.port}"
 
     def should_serve(self, flow: http.HTTPFlow) -> bool:
-        assert flow.reply
         return bool(
             (flow.request.pretty_host, flow.request.port) == (self.host, self.port)
-            and not flow.reply.has_message
-            and not isinstance(flow.reply, DummyReply)  # ignore the HTTP flows of this app loaded from somewhere
+            and flow.live
+            and not flow.error
+            and not flow.response
         )
 
-    def request(self, flow: http.HTTPFlow) -> None:
-        assert flow.reply
+    async def request(self, flow: http.HTTPFlow) -> None:
         if self.should_serve(flow):
-            flow.reply.take()  # pause hook completion
-            asyncio.ensure_future(serve(self.asgi_app, flow))
+            await serve(self.asgi_app, flow)
 
 
 class WSGIApp(ASGIApp):
@@ -54,7 +52,9 @@ HTTP_VERSION_MAP = {
 
 def make_scope(flow: http.HTTPFlow) -> dict:
     # %3F is a quoted question mark
-    quoted_path = urllib.parse.quote_from_bytes(flow.request.data.path).split("%3F", maxsplit=1)
+    quoted_path = urllib.parse.quote_from_bytes(flow.request.data.path).split(
+        "%3F", maxsplit=1
+    )
 
     # (Unicode string) – HTTP request target excluding any query string, with percent-encoded
     # sequences and UTF-8 byte sequences decoded into characters.
@@ -75,15 +75,17 @@ def make_scope(flow: http.HTTPFlow) -> dict:
         },
         "http_version": HTTP_VERSION_MAP.get(flow.request.http_version, "1.1"),
         "method": flow.request.method,
-        "scheme": flow.request.scheme,
+        "scheme": flow.request.scheme.upper(),
         "path": path,
         "raw_path": flow.request.path,
         "query_string": query_string,
-        "headers": list(list(x) for x in flow.request.headers.fields),
-        "client": flow.client_conn.address,
+        "headers": [
+            (name.lower(), value) for (name, value) in flow.request.headers.fields
+        ],
+        "client": flow.client_conn.peername,
         "extensions": {
             "mitmproxy.master": ctx.master,
-        }
+        },
     }
 
 
@@ -91,11 +93,11 @@ async def serve(app, flow: http.HTTPFlow):
     """
     Serves app on flow.
     """
-    assert flow.reply
 
     scope = make_scope(flow)
     done = asyncio.Event()
     received_body = False
+    sent_response = False
 
     async def receive():
         nonlocal received_body
@@ -109,29 +111,28 @@ async def serve(app, flow: http.HTTPFlow):
             # We really don't expect this to be called a second time, but what to do?
             # We just wait until the request is done before we continue here with sending a disconnect.
             await done.wait()
-            return {
-                "type": "http.disconnect"
-            }
+            return {"type": "http.disconnect"}
 
     async def send(event):
         if event["type"] == "http.response.start":
-            flow.response = http.HTTPResponse.make(event["status"], b"", event.get("headers", []))
+            flow.response = http.Response.make(
+                event["status"], b"", event.get("headers", [])
+            )
             flow.response.decode()
         elif event["type"] == "http.response.body":
             flow.response.content += event.get("body", b"")
             if not event.get("more_body", False):
-                flow.reply.ack()
+                nonlocal sent_response
+                sent_response = True
         else:
             raise AssertionError(f"Unexpected event: {event['type']}")
 
     try:
         await app(scope, receive, send)
-        if not flow.reply.has_message:
+        if not sent_response:
             raise RuntimeError(f"no response sent.")
-    except Exception as e:
-        ctx.log.error(f"Error in asgi app: {e}")
-        flow.response = http.HTTPResponse.make(500, b"ASGI Error.")
-        flow.reply.ack(force=True)
+    except Exception:
+        ctx.log.error(f"Error in asgi app:\n{traceback.format_exc(limit=-5)}")
+        flow.response = http.Response.make(500, b"ASGI Error.")
     finally:
-        flow.reply.commit()
         done.set()
