@@ -6,14 +6,15 @@ import inspect
 import sys
 import textwrap
 import types
-import typing
+from collections.abc import Sequence, Callable, Iterable
+from typing import Any, NamedTuple, Optional
 
 import mitmproxy.types
 from mitmproxy import exceptions, command_lexer
 from mitmproxy.command_lexer import unquote
 
 
-def verify_arg_signature(f: typing.Callable, args: typing.Iterable[typing.Any], kwargs: dict) -> None:
+def verify_arg_signature(f: Callable, args: Iterable[Any], kwargs: dict) -> None:
     sig = inspect.signature(f)
     try:
         sig.bind(*args, **kwargs)
@@ -23,25 +24,27 @@ def verify_arg_signature(f: typing.Callable, args: typing.Iterable[typing.Any],
 
 def typename(t: type) -> str:
     """
-        Translates a type to an explanatory string.
+    Translates a type to an explanatory string.
     """
     if t == inspect._empty:  # type: ignore
         raise exceptions.CommandError("missing type annotation")
     to = mitmproxy.types.CommandTypes.get(t, None)
     if not to:
-        raise exceptions.CommandError("unsupported type: %s" % getattr(t, "__name__", t))
+        raise exceptions.CommandError(
+            "unsupported type: %s" % getattr(t, "__name__", t)
+        )
     return to.display
 
 
-def _empty_as_none(x: typing.Any) -> typing.Any:
+def _empty_as_none(x: Any) -> Any:
     if x == inspect.Signature.empty:
         return None
     return x
 
 
-class CommandParameter(typing.NamedTuple):
+class CommandParameter(NamedTuple):
     name: str
-    type: typing.Type
+    type: type
     kind: inspect._ParameterKind = inspect.Parameter.POSITIONAL_OR_KEYWORD
 
     def __str__(self):
@@ -55,9 +58,9 @@ class Command:
     name: str
     manager: "CommandManager"
     signature: inspect.Signature
-    help: typing.Optional[str]
+    help: Optional[str]
 
-    def __init__(self, manager: "CommandManager", name: str, func: typing.Callable) -> None:
+    def __init__(self, manager: "CommandManager", name: str, func: Callable) -> None:
         self.name = name
         self.manager = manager
         self.func = func
@@ -73,16 +76,22 @@ class Command:
         for name, parameter in self.signature.parameters.items():
             t = parameter.annotation
             if not mitmproxy.types.CommandTypes.get(parameter.annotation, None):
-                raise exceptions.CommandError(f"Argument {name} has an unknown type {t} in {func}.")
-        if self.return_type and not mitmproxy.types.CommandTypes.get(self.return_type, None):
-            raise exceptions.CommandError(f"Return type has an unknown type ({self.return_type}) in {func}.")
+                raise exceptions.CommandError(
+                    f"Argument {name} has an unknown type {t} in {func}."
+                )
+        if self.return_type and not mitmproxy.types.CommandTypes.get(
+            self.return_type, None
+        ):
+            raise exceptions.CommandError(
+                f"Return type has an unknown type ({self.return_type}) in {func}."
+            )
 
     @property
-    def return_type(self) -> typing.Optional[typing.Type]:
+    def return_type(self) -> Optional[type]:
         return _empty_as_none(self.signature.return_annotation)
 
     @property
-    def parameters(self) -> typing.List[CommandParameter]:
+    def parameters(self) -> list[CommandParameter]:
         """Returns a list of CommandParameters."""
         ret = []
         for name, param in self.signature.parameters.items():
@@ -97,30 +106,33 @@ class Command:
             ret = ""
         return f"{self.name} {params}{ret}"
 
-    def prepare_args(self, args: typing.Sequence[str]) -> inspect.BoundArguments:
+    def prepare_args(self, args: Sequence[str]) -> inspect.BoundArguments:
         try:
             bound_arguments = self.signature.bind(*args)
         except TypeError:
-            expected = f'Expected: {str(self.signature.parameters)}'
-            received = f'Received: {str(args)}'
-            raise exceptions.CommandError(f"Command argument mismatch: \n    {expected}\n    {received}")
+            expected = f"Expected: {str(self.signature.parameters)}"
+            received = f"Received: {str(args)}"
+            raise exceptions.CommandError(
+                f"Command argument mismatch: \n    {expected}\n    {received}"
+            )
 
         for name, value in bound_arguments.arguments.items():
             param = self.signature.parameters[name]
             convert_to = param.annotation
             if param.kind == param.VAR_POSITIONAL:
                 bound_arguments.arguments[name] = tuple(
-                    parsearg(self.manager, x, convert_to)
-                    for x in value
+                    parsearg(self.manager, x, convert_to) for x in value
                 )
             else:
-                bound_arguments.arguments[name] = parsearg(self.manager, value, convert_to)
+                bound_arguments.arguments[name] = parsearg(
+                    self.manager, value, convert_to
+                )
 
         bound_arguments.apply_defaults()
 
         return bound_arguments
 
-    def call(self, args: typing.Sequence[str]) -> typing.Any:
+    def call(self, args: Sequence[str]) -> Any:
         """
         Call the command with a list of arguments. At this point, all
         arguments are strings.
@@ -138,14 +150,14 @@ class Command:
         return ret
 
 
-class ParseResult(typing.NamedTuple):
+class ParseResult(NamedTuple):
     value: str
-    type: typing.Type
+    type: type
     valid: bool
 
 
 class CommandManager:
-    commands: typing.Dict[str, Command]
+    commands: dict[str, Command]
 
     def __init__(self, master):
         self.master = master
@@ -169,26 +181,25 @@ class CommandManager:
                                 f"Could not load command {o.command_name}: {e}"
                             )
 
-    def add(self, path: str, func: typing.Callable):
+    def add(self, path: str, func: Callable):
         self.commands[path] = Command(self, path, func)
 
     @functools.lru_cache(maxsize=128)
     def parse_partial(
-            self,
-            cmdstr: str
-    ) -> typing.Tuple[typing.Sequence[ParseResult], typing.Sequence[CommandParameter]]:
+        self, cmdstr: str
+    ) -> tuple[Sequence[ParseResult], Sequence[CommandParameter]]:
         """
         Parse a possibly partial command. Return a sequence of ParseResults and a sequence of remainder type help items.
         """
 
-        parts: typing.List[str] = command_lexer.expr.parseString(cmdstr, parseAll=True)
+        parts: list[str] = command_lexer.expr.parseString(cmdstr, parseAll=True)
 
-        parsed: typing.List[ParseResult] = []
-        next_params: typing.List[CommandParameter] = [
+        parsed: list[ParseResult] = []
+        next_params: list[CommandParameter] = [
             CommandParameter("", mitmproxy.types.Cmd),
             CommandParameter("", mitmproxy.types.CmdArgs),
         ]
-        expected: typing.Optional[CommandParameter] = None
+        expected: Optional[CommandParameter] = None
         for part in parts:
             if part.isspace():
                 parsed.append(
@@ -208,13 +219,13 @@ class CommandManager:
                 expected = CommandParameter("", mitmproxy.types.Unknown)
 
             arg_is_known_command = (
-                    expected.type == mitmproxy.types.Cmd and part in self.commands
+                expected.type == mitmproxy.types.Cmd and part in self.commands
             )
             arg_is_unknown_command = (
-                    expected.type == mitmproxy.types.Cmd and part not in self.commands
+                expected.type == mitmproxy.types.Cmd and part not in self.commands
             )
             command_args_following = (
-                    next_params and next_params[0].type == mitmproxy.types.CmdArgs
+                next_params and next_params[0].type == mitmproxy.types.CmdArgs
             )
             if arg_is_known_command and command_args_following:
                 next_params = self.commands[part].parameters + next_params[1:]
@@ -241,7 +252,7 @@ class CommandManager:
 
         return parsed, next_params
 
-    def call(self, command_name: str, *args: typing.Sequence[typing.Any]) -> typing.Any:
+    def call(self, command_name: str, *args: Any) -> Any:
         """
         Call a command with native arguments. May raise CommandError.
         """
@@ -249,7 +260,7 @@ class CommandManager:
             raise exceptions.CommandError("Unknown command: %s" % command_name)
         return self.commands[command_name].func(*args)
 
-    def call_strings(self, command_name: str, args: typing.Sequence[str]) -> typing.Any:
+    def call_strings(self, command_name: str, args: Sequence[str]) -> Any:
         """
         Call a command using a list of string arguments. May raise CommandError.
         """
@@ -258,18 +269,16 @@ class CommandManager:
 
         return self.commands[command_name].call(args)
 
-    def execute(self, cmdstr: str) -> typing.Any:
+    def execute(self, cmdstr: str) -> Any:
         """
         Execute a command string. May raise CommandError.
         """
         parts, _ = self.parse_partial(cmdstr)
         if not parts:
             raise exceptions.CommandError(f"Invalid command: {cmdstr!r}")
-        command_name, *args = [
-            unquote(part.value)
-            for part in parts
-            if part.type != mitmproxy.types.Space
-        ]
+        command_name, *args = (
+            unquote(part.value) for part in parts if part.type != mitmproxy.types.Space
+        )
         return self.call_strings(command_name, args)
 
     def dump(self, out=sys.stdout) -> None:
@@ -282,9 +291,9 @@ class CommandManager:
             print(file=out)
 
 
-def parsearg(manager: CommandManager, spec: str, argtype: type) -> typing.Any:
+def parsearg(manager: CommandManager, spec: str, argtype: type) -> Any:
     """
-        Convert a string to a argument to the appropriate type.
+    Convert a string to a argument to the appropriate type.
     """
     t = mitmproxy.types.CommandTypes.get(argtype, None)
     if not t:
@@ -295,7 +304,7 @@ def parsearg(manager: CommandManager, spec: str, argtype: type) -> typing.Any:
         raise exceptions.CommandError(str(e)) from e
 
 
-def command(name: typing.Optional[str] = None):
+def command(name: Optional[str] = None):
     def decorator(function):
         @functools.wraps(function)
         def wrapper(*args, **kwargs):
@@ -310,9 +319,9 @@ def command(name: typing.Optional[str] = None):
 
 def argument(name, type):
     """
-        Set the type of a command argument at runtime. This is useful for more
-        specific types such as mitmproxy.types.Choice, which we cannot annotate
-        directly as mypy does not like that.
+    Set the type of a command argument at runtime. This is useful for more
+    specific types such as mitmproxy.types.Choice, which we cannot annotate
+    directly as mypy does not like that.
     """
 
     def decorator(f: types.FunctionType) -> types.FunctionType:
