@@ -1,4 +1,4 @@
-import typing
+from typing import Any, Optional
 
 import msgpack
 
@@ -8,7 +8,7 @@ from mitmproxy.contentviews import base
 PARSE_ERROR = object()
 
 
-def parse_msgpack(s: bytes) -> typing.Any:
+def parse_msgpack(s: bytes) -> Any:
     try:
         return msgpack.unpackb(s, raw=False)
     except (ValueError, msgpack.ExtraData, msgpack.FormatError, msgpack.StackError):
@@ -24,10 +24,7 @@ def pretty(value, htchar="    ", lfchar="\n", indent=0):
         ]
         return "{%s}" % (",".join(items) + lfchar + htchar * indent)
     elif type(value) is list:
-        items = [
-            nlch + pretty(item, htchar, lfchar, indent + 1)
-            for item in value
-        ]
+        items = [nlch + pretty(item, htchar, lfchar, indent + 1) for item in value]
         return "[%s]" % (",".join(items) + lfchar + htchar * indent)
     else:
         return repr(value)
@@ -39,12 +36,17 @@ def format_msgpack(data):
 
 class ViewMsgPack(base.View):
     name = "MsgPack"
-    content_types = [
+    __content_types = (
         "application/msgpack",
         "application/x-msgpack",
-    ]
+    )
 
     def __call__(self, data, **metadata):
         data = parse_msgpack(data)
         if data is not PARSE_ERROR:
             return "MsgPack", format_msgpack(data)
+
+    def render_priority(
+        self, data: bytes, *, content_type: Optional[str] = None, **metadata
+    ) -> float:
+        return float(bool(data) and content_type in self.__content_types)
