@@ -1,5 +1,3 @@
-from typing import List  # noqa
-
 from mitmproxy.utils import strutils
 from . import base
 
@@ -9,3 +7,6 @@ class ViewRaw(base.View):
 
     def __call__(self, data, **metadata):
         return "Raw", base.format_text(strutils.bytes_to_escaped_str(data, True))
+
+    def render_priority(self, data: bytes, **metadata) -> float:
+        return 0.1 * float(bool(data))
