@@ -1,5 +1,4 @@
-#!/bin/sh
-# WARNING: do not change the shebang - the Docker base image might not have what you want!
+#!/bin/bash
 
 set -o errexit
 set -o pipefail
@@ -11,7 +10,7 @@ MITMPROXY_PATH="/home/mitmproxy/.mitmproxy"
 if [[ "$1" = "mitmdump" || "$1" = "mitmproxy" || "$1" = "mitmweb" ]]; then
   mkdir -p "$MITMPROXY_PATH"
   chown -R mitmproxy:mitmproxy "$MITMPROXY_PATH"
-  su-exec mitmproxy "$@"
+  gosu mitmproxy "$@"
 else
   exec "$@"
 fi
