@@ -5,8 +5,9 @@ from mitmproxy import ctx
 
 class Benchmark:
     """
-        A simple profiler addon.
+    A simple profiler addon.
     """
+
     def __init__(self):
         self.pr = cProfile.Profile()
         self.started = False
@@ -28,7 +29,7 @@ class Benchmark:
             "-c50",
             "-d5s",
             "http://localhost:%s/benchmark.py" % ctx.master.server.address[1],
-            stdout=asyncio.subprocess.PIPE
+            stdout=asyncio.subprocess.PIPE,
         )
         stdout, _ = await traf.communicate()
         with open(ctx.options.benchmark_save_path + ".bench", mode="wb") as f:
@@ -43,7 +44,7 @@ class Benchmark:
             "benchmark_save_path",
             str,
             "/tmp/profile",
-            "Destination for the .prof and and .bench result files"
+            "Destination for the .prof and and .bench result files",
         )
         ctx.options.update(
             mode="reverse:http://devd.io:10001",
@@ -53,10 +54,10 @@ class Benchmark:
     def running(self):
         if not self.started:
             self.started = True
-            asyncio.get_event_loop().create_task(self.procs())
+            asyncio.get_running_loop().create_task(self.procs())
 
     def done(self):
         self.pr.dump_stats(ctx.options.benchmark_save_path + ".prof")
 
 
-addons = [Benchmark()]
\ No newline at end of file
+addons = [Benchmark()]
