@@ -10,16 +10,19 @@ def check_src_files_have_test():
     missing_test_files = []
 
     excluded = [
-        'mitmproxy/contrib/',
-        'mitmproxy/io/proto/',
-        'mitmproxy/proxy/layers/http',
-        'mitmproxy/test/',
-        'mitmproxy/tools/',
-        'mitmproxy/platform/',
+        "mitmproxy/contrib/",
+        "mitmproxy/io/proto/",
+        "mitmproxy/proxy/layers/http",
+        "mitmproxy/test/",
+        "mitmproxy/tools/",
+        "mitmproxy/platform/",
+        "mitmproxy/utils/pyinstaller/",
+    ]
+    src_files = glob.glob("mitmproxy/**/*.py", recursive=True)
+    src_files = [f for f in src_files if os.path.basename(f) != "__init__.py"]
+    src_files = [
+        f for f in src_files if not any(os.path.normpath(p) in f for p in excluded)
     ]
-    src_files = glob.glob('mitmproxy/**/*.py', recursive=True)
-    src_files = [f for f in src_files if os.path.basename(f) != '__init__.py']
-    src_files = [f for f in src_files if not any(os.path.normpath(p) in f for p in excluded)]
     for f in src_files:
         p = os.path.join("test", os.path.dirname(f), "test_" + os.path.basename(f))
         if not os.path.isfile(p):
@@ -32,16 +35,21 @@ def check_test_files_have_src():
     unknown_test_files = []
 
     excluded = [
-        'test/mitmproxy/data/',
-        'test/mitmproxy/net/data/',
-        '/tservers.py',
-        '/conftest.py',
+        "test/mitmproxy/data/",
+        "test/mitmproxy/net/data/",
+        "/tservers.py",
+        "/conftest.py",
+    ]
+    test_files = glob.glob("test/mitmproxy/**/*.py", recursive=True)
+    test_files = [f for f in test_files if os.path.basename(f) != "__init__.py"]
+    test_files = [
+        f for f in test_files if not any(os.path.normpath(p) in f for p in excluded)
     ]
-    test_files = glob.glob('test/mitmproxy/**/*.py', recursive=True)
-    test_files = [f for f in test_files if os.path.basename(f) != '__init__.py']
-    test_files = [f for f in test_files if not any(os.path.normpath(p) in f for p in excluded)]
     for f in test_files:
-        p = os.path.join(re.sub('^test/', '', os.path.dirname(f)), re.sub('^test_', '', os.path.basename(f)))
+        p = os.path.join(
+            re.sub("^test/", "", os.path.dirname(f)),
+            re.sub("^test_", "", os.path.basename(f)),
+        )
         if not os.path.isfile(p):
             unknown_test_files.append((f, p))
 
@@ -67,5 +75,5 @@ def main():
     sys.exit(exitcode)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
