@@ -3,6 +3,7 @@ import pytest
 from mitmproxy.addons import modifybody
 from mitmproxy.test import taddons
 from mitmproxy.test import tflow
+from mitmproxy.test.tutils import tresp
 
 
 class TestModifyBody:
@@ -21,7 +22,7 @@ class TestModifyBody:
                 modify_body=[
                     "/~q/foo/bar",
                     "/~s/foo/bar",
-                ]
+                ],
             )
             f = tflow.tflow()
             f.request.content = b"foo"
@@ -41,14 +42,14 @@ class TestModifyBody:
             f = tflow.tflow()
             f.request.content = b"foo"
             if take:
-                f.reply.take()
+                f.response = tresp()
             mb.request(f)
             assert (f.request.content == b"bar") ^ take
 
             f = tflow.tflow(resp=True)
             f.response.content = b"foo"
             if take:
-                f.reply.take()
+                f.kill()
             mb.response(f)
             assert (f.response.content == b"bar") ^ take
 
@@ -62,7 +63,7 @@ class TestModifyBody:
                     "/bar/baz",
                     "/foo/oh noes!",
                     "/bar/oh noes!",
-                ]
+                ],
             )
             f = tflow.tflow()
             f.request.content = b"foo"
@@ -76,31 +77,21 @@ class TestModifyBodyFile:
         with taddons.context(mb) as tctx:
             tmpfile = tmpdir.join("replacement")
             tmpfile.write("bar")
-            tctx.configure(
-                mb,
-                modify_body=["/~q/foo/@" + str(tmpfile)]
-            )
+            tctx.configure(mb, modify_body=["/~q/foo/@" + str(tmpfile)])
             f = tflow.tflow()
             f.request.content = b"foo"
             mb.request(f)
             assert f.request.content == b"bar"
 
-    @pytest.mark.asyncio
     async def test_nonexistent(self, tmpdir):
         mb = modifybody.ModifyBody()
         with taddons.context(mb) as tctx:
             with pytest.raises(Exception, match="Invalid file path"):
-                tctx.configure(
-                    mb,
-                    modify_body=["/~q/foo/@nonexistent"]
-                )
+                tctx.configure(mb, modify_body=["/~q/foo/@nonexistent"])
 
             tmpfile = tmpdir.join("replacement")
             tmpfile.write("bar")
-            tctx.configure(
-                mb,
-                modify_body=["/~q/foo/@" + str(tmpfile)]
-            )
+            tctx.configure(mb, modify_body=["/~q/foo/@" + str(tmpfile)])
             tmpfile.remove()
             f = tflow.tflow()
             f.request.content = b"foo"
