@@ -1,5 +1,6 @@
 import asyncio
 import os
+import re
 import sys
 import traceback
 
@@ -8,35 +9,28 @@ import pytest
 from mitmproxy import addonmanager
 from mitmproxy import exceptions
 from mitmproxy.addons import script
+from mitmproxy.proxy.layers.http import HttpRequestHook
 from mitmproxy.test import taddons
 from mitmproxy.test import tflow
+from mitmproxy.tools import main
 
 
 # We want this to be speedy for testing
 script.ReloadInterval = 0.1
 
 
-@pytest.mark.asyncio
 async def test_load_script(tdata):
     with taddons.context() as tctx:
         ns = script.load_script(
-            tdata.path(
-                "mitmproxy/data/addonscripts/recorder/recorder.py"
-            )
+            tdata.path("mitmproxy/data/addonscripts/recorder/recorder.py")
         )
         assert ns.addons
 
-        script.load_script(
-            "nonexistent"
-        )
-        assert await tctx.master.await_log("No such file or directory")
+        script.load_script("nonexistent")
+        await tctx.master.await_log("No such file or directory")
 
-        script.load_script(
-            tdata.path(
-                "mitmproxy/data/addonscripts/recorder/error.py"
-            )
-        )
-        assert await tctx.master.await_log("invalid syntax")
+        script.load_script(tdata.path("mitmproxy/data/addonscripts/recorder/error.py"))
+        await tctx.master.await_log("invalid syntax")
 
 
 def test_load_fullname(tdata):
@@ -45,16 +39,10 @@ def test_load_fullname(tdata):
     This only succeeds if they get assigned different basenames.
 
     """
-    ns = script.load_script(
-        tdata.path(
-            "mitmproxy/data/addonscripts/addon.py"
-        )
-    )
+    ns = script.load_script(tdata.path("mitmproxy/data/addonscripts/addon.py"))
     assert ns.addons
     ns2 = script.load_script(
-        tdata.path(
-            "mitmproxy/data/addonscripts/same_filename/addon.py"
-        )
+        tdata.path("mitmproxy/data/addonscripts/same_filename/addon.py")
     )
     assert ns.name != ns2.name
     assert not hasattr(ns2, "addons")
@@ -73,34 +61,27 @@ class TestScript:
         """
         path = tdata.path("mitmproxy/data/addonscripts/recorder/recorder.py")
 
-        s = script.Script(
-            f'"{path}"',
-            False
-        )
+        s = script.Script(f'"{path}"', False)
         assert '"' not in s.fullpath
 
-    @pytest.mark.asyncio
     async def test_simple(self, tdata):
         sc = script.Script(
-            tdata.path(
-                "mitmproxy/data/addonscripts/recorder/recorder.py"
-            ),
+            tdata.path("mitmproxy/data/addonscripts/recorder/recorder.py"),
             True,
         )
         with taddons.context(sc) as tctx:
             tctx.configure(sc)
-            await tctx.master.await_log("recorder running")
+            await tctx.master.await_log("recorder configure")
             rec = tctx.master.addons.get("recorder")
 
             assert rec.call_log[0][0:2] == ("recorder", "load")
 
             rec.call_log = []
             f = tflow.tflow(resp=True)
-            tctx.master.addons.trigger("request", f)
+            tctx.master.addons.trigger(HttpRequestHook(f))
 
             assert rec.call_log[0][1] == "request"
 
-    @pytest.mark.asyncio
     async def test_reload(self, tmpdir):
         with taddons.context() as tctx:
             f = tmpdir.join("foo.py")
@@ -108,7 +89,7 @@ class TestScript:
             f.write("\n")
             sc = script.Script(str(f), True)
             tctx.configure(sc)
-            assert await tctx.master.await_log("Loading")
+            await tctx.master.await_log("Loading")
 
             tctx.master.clear()
             for i in range(20):
@@ -119,7 +100,6 @@ class TestScript:
             else:
                 raise AssertionError("No reload seen")
 
-    @pytest.mark.asyncio
     async def test_exception(self, tdata):
         with taddons.context() as tctx:
             sc = script.Script(
@@ -127,16 +107,15 @@ class TestScript:
                 True,
             )
             tctx.master.addons.add(sc)
-            await tctx.master.await_log("error running")
+            await tctx.master.await_log("error load")
             tctx.configure(sc)
 
             f = tflow.tflow(resp=True)
-            tctx.master.addons.trigger("request", f)
+            tctx.master.addons.trigger(HttpRequestHook(f))
 
-            assert await tctx.master.await_log("ValueError: Error!")
-            assert await tctx.master.await_log("error.py")
+            await tctx.master.await_log("ValueError: Error!")
+            await tctx.master.await_log("error.py")
 
-    @pytest.mark.asyncio
     async def test_optionexceptions(self, tdata):
         with taddons.context() as tctx:
             sc = script.Script(
@@ -145,21 +124,18 @@ class TestScript:
             )
             tctx.master.addons.add(sc)
             tctx.configure(sc)
-            assert await tctx.master.await_log("Options Error")
+            await tctx.master.await_log("Options Error")
 
-    @pytest.mark.asyncio
     async def test_addon(self, tdata):
         with taddons.context() as tctx:
-            sc = script.Script(
-                tdata.path(
-                    "mitmproxy/data/addonscripts/addon.py"
-                ),
-                True
-            )
+            sc = script.Script(tdata.path("mitmproxy/data/addonscripts/addon.py"), True)
             tctx.master.addons.add(sc)
             await tctx.master.await_log("addon running")
             assert sc.ns.event_log == [
-                'scriptload', 'addonload', 'scriptconfigure', 'addonconfigure'
+                "scriptload",
+                "addonload",
+                "scriptconfigure",
+                "addonconfigure",
             ]
 
 
@@ -182,7 +158,6 @@ class TestCutTraceback:
 
 
 class TestScriptLoader:
-    @pytest.mark.asyncio
     async def test_script_run(self, tdata):
         rp = tdata.path("mitmproxy/data/addonscripts/recorder/recorder.py")
         sc = script.ScriptLoader()
@@ -191,34 +166,32 @@ class TestScriptLoader:
             await tctx.master.await_log("recorder response")
             debug = [i.msg for i in tctx.master.logs if i.level == "debug"]
             assert debug == [
-                'recorder running', 'recorder configure',
-                'recorder requestheaders', 'recorder request',
-                'recorder responseheaders', 'recorder response'
+                "recorder configure",
+                "recorder running",
+                "recorder requestheaders",
+                "recorder request",
+                "recorder responseheaders",
+                "recorder response",
             ]
 
-    @pytest.mark.asyncio
     async def test_script_run_nonexistent(self):
         sc = script.ScriptLoader()
         with taddons.context(sc) as tctx:
             sc.script_run([tflow.tflow(resp=True)], "/")
-            assert await tctx.master.await_log("No such script")
+            await tctx.master.await_log("No such script")
 
-    def test_simple(self, tdata):
+    async def test_simple(self, tdata):
         sc = script.ScriptLoader()
         with taddons.context(loadcore=False) as tctx:
             tctx.master.addons.add(sc)
             sc.running()
             assert len(tctx.master.addons) == 1
             tctx.master.options.update(
-                scripts = [
-                    tdata.path(
-                        "mitmproxy/data/addonscripts/recorder/recorder.py"
-                    )
-                ]
+                scripts=[tdata.path("mitmproxy/data/addonscripts/recorder/recorder.py")]
             )
             assert len(tctx.master.addons) == 1
             assert len(sc.addons) == 1
-            tctx.master.options.update(scripts = [])
+            tctx.master.options.update(scripts=[])
             assert len(tctx.master.addons) == 1
             assert len(sc.addons) == 0
 
@@ -226,30 +199,28 @@ class TestScriptLoader:
         sc = script.ScriptLoader()
         with taddons.context(sc) as tctx:
             with pytest.raises(exceptions.OptionsError):
-                tctx.configure(
-                    sc,
-                    scripts = ["one", "one"]
-                )
+                tctx.configure(sc, scripts=["one", "one"])
 
-    @pytest.mark.asyncio
     async def test_script_deletion(self, tdata):
         tdir = tdata.path("mitmproxy/data/addonscripts/")
-        with open(tdir + "/dummy.py", 'w') as f:
+        with open(tdir + "/dummy.py", "w") as f:
             f.write("\n")
 
         with taddons.context() as tctx:
             sl = script.ScriptLoader()
             tctx.master.addons.add(sl)
-            tctx.configure(sl, scripts=[tdata.path("mitmproxy/data/addonscripts/dummy.py")])
+            tctx.configure(
+                sl, scripts=[tdata.path("mitmproxy/data/addonscripts/dummy.py")]
+            )
             await tctx.master.await_log("Loading")
 
             os.remove(tdata.path("mitmproxy/data/addonscripts/dummy.py"))
 
             await tctx.master.await_log("Removing")
+            await asyncio.sleep(0.1)
             assert not tctx.options.scripts
             assert not sl.addons
 
-    @pytest.mark.asyncio
     async def test_script_error_handler(self):
         path = "/sample/path/example.py"
         exc = SyntaxError
@@ -257,12 +228,11 @@ class TestScriptLoader:
         tb = True
         with taddons.context() as tctx:
             script.script_error_handler(path, exc, msg, tb)
-            assert await tctx.master.await_log("/sample/path/example.py")
-            assert await tctx.master.await_log("Error raised")
-            assert await tctx.master.await_log("lineno")
-            assert await tctx.master.await_log("NoneType")
+            await tctx.master.await_log("/sample/path/example.py")
+            await tctx.master.await_log("Error raised")
+            await tctx.master.await_log("lineno")
+            await tctx.master.await_log("NoneType")
 
-    @pytest.mark.asyncio
     async def test_order(self, tdata):
         rec = tdata.path("mitmproxy/data/addonscripts/recorder")
         sc = script.ScriptLoader()
@@ -270,61 +240,84 @@ class TestScriptLoader:
         with taddons.context(sc) as tctx:
             tctx.configure(
                 sc,
-                scripts = [
+                scripts=[
                     "%s/a.py" % rec,
                     "%s/b.py" % rec,
                     "%s/c.py" % rec,
-                ]
+                ],
             )
             await tctx.master.await_log("configure")
             debug = [i.msg for i in tctx.master.logs if i.level == "debug"]
             assert debug == [
-                'a load',
-                'a running',
-                'a configure',
-
-                'b load',
-                'b running',
-                'b configure',
-
-                'c load',
-                'c running',
-                'c configure',
+                "a load",
+                "a configure",
+                "a running",
+                "b load",
+                "b configure",
+                "b running",
+                "c load",
+                "c configure",
+                "c running",
             ]
 
             tctx.master.clear()
             tctx.configure(
                 sc,
-                scripts = [
+                scripts=[
                     "%s/c.py" % rec,
                     "%s/a.py" % rec,
                     "%s/b.py" % rec,
-                ]
+                ],
             )
 
-            await tctx.master.await_log("c configure")
+            await tctx.master.await_log("b configure")
             debug = [i.msg for i in tctx.master.logs if i.level == "debug"]
             assert debug == [
-                'c configure',
-                'a configure',
-                'b configure',
+                "c configure",
+                "a configure",
+                "b configure",
             ]
 
             tctx.master.clear()
             tctx.configure(
                 sc,
-                scripts = [
+                scripts=[
                     "%s/e.py" % rec,
                     "%s/a.py" % rec,
-                ]
+                ],
             )
-            await tctx.master.await_log("Loading")
+            await tctx.master.await_log("e configure")
             debug = [i.msg for i in tctx.master.logs if i.level == "debug"]
             assert debug == [
-                'c done',
-                'b done',
-                'a configure',
-                'e load',
-                'e running',
-                'e configure',
+                "c done",
+                "b done",
+                "a configure",
+                "e load",
+                "e configure",
+                "e running",
             ]
+
+            # stop reload tasks
+            tctx.configure(sc, scripts=[])
+
+
+def test_order(tdata, capsys):
+    """Integration test: Make sure that the runtime hooks are triggered on startup in the correct order."""
+    main.mitmdump(
+        [
+            "-n",
+            "-s",
+            tdata.path("mitmproxy/data/addonscripts/recorder/recorder.py"),
+            "-s",
+            tdata.path("mitmproxy/data/addonscripts/shutdown.py"),
+        ]
+    )
+    assert re.match(
+        r"Loading script.+recorder.py\n"
+        r"\('recorder', 'load', .+\n"
+        r"\('recorder', 'configure', .+\n"
+        r"Loading script.+shutdown.py\n"
+        r"\('recorder', 'running', .+\n"
+        r"\('recorder', 'done', .+\n$",
+        capsys.readouterr().out,
+    )
