@@ -8,17 +8,19 @@ def test_view_javascript():
     v = full_eval(javascript.ViewJavaScript())
     assert v(b"[1, 2, 3]")
     assert v(b"[1, 2, 3")
-    assert v(b"function(a){[1, 2, 3]}") == ("JavaScript", [
-        [('text', 'function(a) {')],
-        [('text', '  [1, 2, 3]')],
-        [('text', '}')]
-    ])
+    assert v(b"function(a){[1, 2, 3]}") == (
+        "JavaScript",
+        [[("text", "function(a) {")], [("text", "  [1, 2, 3]")], [("text", "}")]],
+    )
     assert v(b"\xfe")  # invalid utf-8
 
 
-@pytest.mark.parametrize("filename", [
-    "simple.js",
-])
+@pytest.mark.parametrize(
+    "filename",
+    [
+        "simple.js",
+    ],
+)
 def test_format_xml(filename, tdata):
     path = tdata.path("mitmproxy/contentviews/test_js_data/" + filename)
     with open(path) as f:
@@ -31,7 +33,7 @@ def test_format_xml(filename, tdata):
 
 def test_render_priority():
     v = javascript.ViewJavaScript()
-    assert v.render_priority(b"", content_type="application/x-javascript")
-    assert v.render_priority(b"", content_type="application/javascript")
-    assert v.render_priority(b"", content_type="text/javascript")
-    assert not v.render_priority(b"", content_type="text/plain")
+    assert v.render_priority(b"data", content_type="application/x-javascript")
+    assert v.render_priority(b"data", content_type="application/javascript")
+    assert v.render_priority(b"data", content_type="text/javascript")
+    assert not v.render_priority(b"data", content_type="text/plain")
