@@ -18,17 +18,9 @@ def test_parse_msgpack():
 
 
 def test_format_msgpack():
-    assert list(msgpack.format_msgpack({
-        "data": [
-            "str",
-            42,
-            True,
-            False,
-            None,
-            {},
-            []
-        ]
-    }))
+    assert list(
+        msgpack.format_msgpack({"data": ["str", 42, True, False, None, {}, []]})
+    )
 
 
 def test_view_msgpack():
@@ -44,3 +36,10 @@ def test_view_msgpack():
 def test_view_msgpack_doesnt_crash(data):
     v = full_eval(msgpack.ViewMsgPack())
     v(data)
+
+
+def test_render_priority():
+    v = msgpack.ViewMsgPack()
+    assert v.render_priority(b"data", content_type="application/msgpack")
+    assert v.render_priority(b"data", content_type="application/x-msgpack")
+    assert not v.render_priority(b"data", content_type="text/plain")
