@@ -14,9 +14,9 @@ def test_view_protobuf_request(tdata):
         raw = f.read()
     content_type, output = v(raw)
     assert content_type == "Protobuf"
-    assert output == [[('text', '1: 3bbc333c-e61c-433b-819a-0b9a8cc103b8')]]
+    assert output == [[("text", "1: 3bbc333c-e61c-433b-819a-0b9a8cc103b8")]]
     with pytest.raises(ValueError, match="Failed to parse input."):
-        v(b'foobar')
+        v(b"foobar")
 
 
 @pytest.mark.parametrize("filename", ["protobuf02.bin", "protobuf03.bin"])
@@ -28,3 +28,10 @@ def test_format_pbuf(filename, tdata):
         expected = f.read()
 
     assert protobuf.format_pbuf(input) == expected
+
+
+def test_render_priority():
+    v = protobuf.ViewProtobuf()
+    assert v.render_priority(b"data", content_type="application/x-protobuf")
+    assert v.render_priority(b"data", content_type="application/x-protobuffer")
+    assert not v.render_priority(b"data", content_type="text/plain")
