@@ -1,4 +1,4 @@
-import typing
+from typing import Optional
 
 from mitmproxy import exceptions
 
@@ -6,16 +6,14 @@ from mitmproxy import exceptions
 class OptionAddon:
     def load(self, loader):
         loader.add_option(
-            name = "optionaddon",
-            typespec = typing.Optional[int],
-            default = None,
-            help = "Option Addon",
+            name="optionaddon",
+            typespec=Optional[int],
+            default=None,
+            help="Option Addon",
         )
 
     def configure(self, updates):
         raise exceptions.OptionsError("Options Error")
 
-addons = [
-    OptionAddon()
-]
 
+addons = [OptionAddon()]
