@@ -6,17 +6,20 @@ from mitmproxy import flowfilter, http
 
 
 class TestParsing:
-
     def _dump(self, x):
         c = io.StringIO()
         x.dump(fp=c)
         assert c.getvalue()
 
     def test_parse_err(self):
-        assert flowfilter.parse("~h [") is None
+        with pytest.raises(ValueError, match="Empty filter"):
+            flowfilter.parse("")
+        with pytest.raises(ValueError, match="Invalid filter"):
+            flowfilter.parse("~b")
+        with pytest.raises(ValueError, match="Invalid filter"):
+            flowfilter.parse("~h [")
 
     def test_simple(self):
-        assert not flowfilter.parse("~b")
         assert flowfilter.parse("~q")
         assert flowfilter.parse("~c 10")
         assert flowfilter.parse("~m foobar")
@@ -82,7 +85,6 @@ class TestParsing:
 
 
 class TestMatchingHTTPFlow:
-
     def req(self):
         return tflow.tflow()
 
@@ -150,7 +152,7 @@ class TestMatchingHTTPFlow:
         t = tflow.tflow()
         t.marked = ":default:"
         assert not self.q("~marker X", t)
-        t.marked = 'X'
+        t.marked = "X"
         assert self.q("~marker X", t)
 
     def test_head(self):
@@ -185,30 +187,30 @@ class TestMatchingHTTPFlow:
         assert not self.q("~bq message", q)
         assert not self.q("~bq message", s)
 
-        s.response.text = 'яч'           # Cyrillic
+        s.response.text = "яч"  # Cyrillic
         assert self.q("~bs яч", s)
-        s.response.text = '测试'          # Chinese
-        assert self.q('~bs 测试', s)
-        s.response.text = 'ॐ'            # Hindi
-        assert self.q('~bs ॐ', s)
-        s.response.text = 'لله'           # Arabic
-        assert self.q('~bs لله', s)
-        s.response.text = 'θεός'          # Greek
-        assert self.q('~bs θεός', s)
-        s.response.text = 'לוהים'          # Hebrew
-        assert self.q('~bs לוהים', s)
-        s.response.text = '神'            # Japanese
-        assert self.q('~bs 神', s)
-        s.response.text = '하나님'         # Korean
-        assert self.q('~bs 하나님', s)
-        s.response.text = 'Äÿ'            # Latin
-        assert self.q('~bs Äÿ', s)
+        s.response.text = "测试"  # Chinese
+        assert self.q("~bs 测试", s)
+        s.response.text = "ॐ"  # Hindi
+        assert self.q("~bs ॐ", s)
+        s.response.text = "لله"  # Arabic
+        assert self.q("~bs لله", s)
+        s.response.text = "θεός"  # Greek
+        assert self.q("~bs θεός", s)
+        s.response.text = "לוהים"  # Hebrew
+        assert self.q("~bs לוהים", s)
+        s.response.text = "神"  # Japanese
+        assert self.q("~bs 神", s)
+        s.response.text = "하나님"  # Korean
+        assert self.q("~bs 하나님", s)
+        s.response.text = "Äÿ"  # Latin
+        assert self.q("~bs Äÿ", s)
 
         assert not self.q("~bs nomatch", s)
         assert not self.q("~bs content", q)
         assert not self.q("~bs content", s)
         assert not self.q("~bs message", q)
-        s.response.text = 'message'
+        s.response.text = "message"
         assert self.q("~bs message", s)
 
     def test_body(self):
@@ -264,9 +266,9 @@ class TestMatchingHTTPFlow:
         assert self.q("~src 127.0.0.1:22", q)
 
         q.client_conn.peername = None
-        assert not self.q('~src address:22', q)
+        assert not self.q("~src address:22", q)
         q.client_conn = None
-        assert not self.q('~src address:22', q)
+        assert not self.q("~src address:22", q)
 
     def test_dst(self):
         q = self.req()
@@ -278,9 +280,9 @@ class TestMatchingHTTPFlow:
         assert self.q("~dst address:22", q)
 
         q.server_conn.address = None
-        assert not self.q('~dst address:22', q)
+        assert not self.q("~dst address:22", q)
         q.server_conn = None
-        assert not self.q('~dst address:22', q)
+        assert not self.q("~dst address:22", q)
 
     def test_and(self):
         s = self.resp()
@@ -327,12 +329,65 @@ class TestMatchingHTTPFlow:
         assert self.q("~meta string", f)
         assert self.q("~meta key", f)
         assert self.q("~meta value", f)
-        assert self.q("~meta \"b: string\"", f)
+        assert self.q('~meta "b: string"', f)
         assert self.q("~meta \"'key': 'value'\"", f)
 
 
-class TestMatchingTCPFlow:
+class TestMatchingDNSFlow:
+    def req(self):
+        return tflow.tdnsflow()
 
+    def resp(self):
+        return tflow.tdnsflow(resp=True)
+
+    def err(self):
+        return tflow.tdnsflow(err=True)
+
+    def q(self, q, o):
+        return flowfilter.parse(q)(o)
+
+    def test_dns(self):
+        s = self.req()
+        assert self.q("~dns", s)
+        assert not self.q("~http", s)
+        assert not self.q("~tcp", s)
+
+    def test_freq_fresp(self):
+        q = self.req()
+        s = self.resp()
+
+        assert self.q("~q", q)
+        assert not self.q("~q", s)
+
+        assert not self.q("~s", q)
+        assert self.q("~s", s)
+
+    def test_ferr(self):
+        e = self.err()
+        assert self.q("~e", e)
+
+    def test_body(self):
+        q = self.req()
+        s = self.resp()
+        assert not self.q("~b nonexistent", q)
+        assert self.q("~b dns.google", q)
+        assert self.q("~b 8.8.8.8", s)
+
+        assert not self.q("~bq 8.8.8.8", s)
+        assert self.q("~bq dns.google", q)
+        assert self.q("~bq dns.google", s)
+
+        assert not self.q("~bs dns.google", q)
+        assert self.q("~bs dns.google", s)
+        assert self.q("~bs 8.8.8.8", s)
+
+    def test_url(self):
+        f = self.req()
+        assert not self.q("~u whatever", f)
+        assert self.q("~u dns.google", f)
+
+
+class TestMatchingTCPFlow:
     def flow(self):
         return tflow.ttcpflow()
 
@@ -457,7 +512,6 @@ class TestMatchingTCPFlow:
 
 
 class TestMatchingWebSocketFlow:
-
     def flow(self) -> http.HTTPFlow:
         return tflow.twebsocketflow()
 
@@ -553,7 +607,6 @@ class TestMatchingWebSocketFlow:
 
 
 class TestMatchingDummyFlow:
-
     def flow(self):
         return tflow.tdummyflow()
 
@@ -568,6 +621,8 @@ class TestMatchingDummyFlow:
         f = self.flow()
         f.server_conn = tflow.tserver_conn()
 
+        assert self.q("~all", f)
+
         assert not self.q("~a", f)
 
         assert not self.q("~b whatever", f)
@@ -614,7 +669,7 @@ class TestMatchingDummyFlow:
         assert self.q("~comment .", f)
 
 
-@patch('traceback.extract_tb')
+@patch("traceback.extract_tb")
 def test_pyparsing_bug(extract_tb):
     """https://github.com/mitmproxy/mitmproxy/issues/1087"""
     # The text is a string with leading and trailing whitespace stripped; if the source is not available it is None.
@@ -624,7 +679,7 @@ def test_pyparsing_bug(extract_tb):
 
 def test_match():
     with pytest.raises(ValueError):
-        flowfilter.match('[foobar', None)
+        flowfilter.match("[foobar", None)
 
     assert flowfilter.match(None, None)
-    assert not flowfilter.match('foobar', None)
+    assert not flowfilter.match("foobar", None)
