@@ -1,7 +1,7 @@
 import argparse
 
 from mitmproxy import options
-from mitmproxy.tools import cmdline, web, dump, console
+from mitmproxy.tools import cmdline
 from mitmproxy.tools import main
 
 
@@ -10,25 +10,22 @@ def test_common():
     opts = options.Options()
     cmdline.common_options(parser, opts)
     args = parser.parse_args(args=[])
-    assert main.process_options(parser, opts, args)
+    main.process_options(parser, opts, args)
 
 
 def test_mitmproxy():
     opts = options.Options()
-    console.master.ConsoleMaster(opts)
     ap = cmdline.mitmproxy(opts)
     assert ap
 
 
 def test_mitmdump():
     opts = options.Options()
-    dump.DumpMaster(opts)
     ap = cmdline.mitmdump(opts)
     assert ap
 
 
 def test_mitmweb():
     opts = options.Options()
-    web.master.WebMaster(opts)
     ap = cmdline.mitmweb(opts)
     assert ap
