@@ -27,14 +27,14 @@ def test_escape_control_characters():
     assert strutils.escape_control_characters("\nne", False) == ".ne"
     assert strutils.escape_control_characters("\u2605") == "\u2605"
     assert (
-        strutils.escape_control_characters(bytes(bytearray(range(128))).decode()) ==
-        '.........\t\n..\r.................. !"#$%&\'()*+,-./0123456789:;<'
-        '=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~.'
+        strutils.escape_control_characters(bytes(bytearray(range(128))).decode())
+        == ".........\t\n..\r.................. !\"#$%&'()*+,-./0123456789:;<"
+        "=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~."
     )
     assert (
-        strutils.escape_control_characters(bytes(bytearray(range(128))).decode(), False) ==
-        '................................ !"#$%&\'()*+,-./0123456789:;<'
-        '=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~.'
+        strutils.escape_control_characters(bytes(bytearray(range(128))).decode(), False)
+        == "................................ !\"#$%&'()*+,-./0123456789:;<"
+        "=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~."
     )
 
     with pytest.raises(ValueError):
@@ -45,7 +45,7 @@ def test_bytes_to_escaped_str():
     assert strutils.bytes_to_escaped_str(b"foo") == "foo"
     assert strutils.bytes_to_escaped_str(b"\b") == r"\x08"
     assert strutils.bytes_to_escaped_str(br"&!?=\)") == r"&!?=\\)"
-    assert strutils.bytes_to_escaped_str(b'\xc3\xbc') == r"\xc3\xbc"
+    assert strutils.bytes_to_escaped_str(b"\xc3\xbc") == r"\xc3\xbc"
     assert strutils.bytes_to_escaped_str(b"'") == r"'"
     assert strutils.bytes_to_escaped_str(b'"') == r'"'
 
@@ -58,7 +58,9 @@ def test_bytes_to_escaped_str():
     assert strutils.bytes_to_escaped_str(b"\n", True) == "\n"
     assert strutils.bytes_to_escaped_str(b"\\n", True) == "\\ \\ n".replace(" ", "")
     assert strutils.bytes_to_escaped_str(b"\\\n", True) == "\\ \\ \n".replace(" ", "")
-    assert strutils.bytes_to_escaped_str(b"\\\\n", True) == "\\ \\ \\ \\ n".replace(" ", "")
+    assert strutils.bytes_to_escaped_str(b"\\\\n", True) == "\\ \\ \\ \\ n".replace(
+        " ", ""
+    )
 
     with pytest.raises(ValueError):
         strutils.bytes_to_escaped_str("such unicode")
@@ -70,7 +72,7 @@ def test_escaped_str_to_bytes():
     assert strutils.escaped_str_to_bytes("&!?=\\\\)") == br"&!?=\)"
     assert strutils.escaped_str_to_bytes("\\x08") == b"\b"
     assert strutils.escaped_str_to_bytes("&!?=\\\\)") == br"&!?=\)"
-    assert strutils.escaped_str_to_bytes("\u00fc") == b'\xc3\xbc'
+    assert strutils.escaped_str_to_bytes("\u00fc") == b"\xc3\xbc"
 
     with pytest.raises(ValueError):
         strutils.escaped_str_to_bytes(b"very byte")
@@ -101,29 +103,37 @@ def test_hexdump():
 
 ESCAPE_QUOTES = [
     "'" + strutils.SINGLELINE_CONTENT + strutils.NO_ESCAPE + "'",
-    '"' + strutils.SINGLELINE_CONTENT + strutils.NO_ESCAPE + '"'
+    '"' + strutils.SINGLELINE_CONTENT + strutils.NO_ESCAPE + '"',
 ]
 
 
 def test_split_special_areas():
     assert strutils.split_special_areas("foo", ESCAPE_QUOTES) == ["foo"]
-    assert strutils.split_special_areas("foo 'bar' baz", ESCAPE_QUOTES) == ["foo ", "'bar'", " baz"]
+    assert strutils.split_special_areas("foo 'bar' baz", ESCAPE_QUOTES) == [
+        "foo ",
+        "'bar'",
+        " baz",
+    ]
+    assert strutils.split_special_areas("""foo 'b\\'a"r' baz""", ESCAPE_QUOTES) == [
+        "foo ",
+        "'b\\'a\"r'",
+        " baz",
+    ]
     assert strutils.split_special_areas(
-        """foo 'b\\'a"r' baz""",
-        ESCAPE_QUOTES
-    ) == ["foo ", "'b\\'a\"r'", " baz"]
-    assert strutils.split_special_areas(
-        "foo\n/*bar\nbaz*/\nqux",
-        [r'/\*[\s\S]+?\*/']
+        "foo\n/*bar\nbaz*/\nqux", [r"/\*[\s\S]+?\*/"]
     ) == ["foo\n", "/*bar\nbaz*/", "\nqux"]
-    assert strutils.split_special_areas(
-        "foo\n//bar\nbaz",
-        [r'//.+$']
-    ) == ["foo\n", "//bar", "\nbaz"]
+    assert strutils.split_special_areas("foo\n//bar\nbaz", [r"//.+$"]) == [
+        "foo\n",
+        "//bar",
+        "\nbaz",
+    ]
 
 
 def test_escape_special_areas():
-    assert strutils.escape_special_areas('foo "bar" baz', ESCAPE_QUOTES, "*") == 'foo "bar" baz'
+    assert (
+        strutils.escape_special_areas('foo "bar" baz', ESCAPE_QUOTES, "*")
+        == 'foo "bar" baz'
+    )
     esc = strutils.escape_special_areas('foo "b*r" b*z', ESCAPE_QUOTES, "*")
     assert esc == 'foo "b\ue02ar" b*z'
     assert strutils.unescape_special_areas(esc) == 'foo "b*r" b*z'
